==> standwithukraine-1.2.6.tar.gz: standwithukraine/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Maintainers


INTRODUCTION
------------

The StandWithUkraine 🇺🇦 provides a message to show your support for Ukrainians
on the top of your website. Also, the message can be placed on the left or right
border of the page.

 * For a full description of the module, visit the project page:
   https://www.drupal.org/project/standwithukraine

 * To submit bug reports and feature suggestions, or track changes:
   https://www.drupal.org/project/issues/standwithukraine


REQUIREMENTS
------------

This module requires no modules outside of Drupal core.


INSTALLATION
------------

 * Install as you would normally install a contributed Drupal module. Visit
   https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

 * Configure the user permissions in Administration » People » Permissions:

   - Administer StandWithUkraine

     Users with this permission will configure module settings.

   - Hide message and use original favicon

     Users with this permission will not see the message and overridden favicon.

   - Hide message

     Users with this permission will not see the message.

   - Use original favicon

     Users with this permission will not see overridden favicon.

 * Customize the module settings in Administration » Configuration »
   User interface » StandWithUkraine 🇺🇦.


MAINTAINERS
-----------

Current maintainers:
 * Oleksandr Horbatiuk (chmez) - https://www.drupal.org/user/3071411

==> standwithukraine-1.3.0.tar.gz: standwithukraine/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Maintainers


INTRODUCTION
------------

The StandWithUkraine 🇺🇦 provides the following features to show your support for
Ukrainians:

 1. Message on the background of the flag which can be attached to one of the
    three sides of the page (top, right, left).

 2. Painting the favicon in the colors of the Ukraine flag.

 3. A block contains a message provided by the first feature.

 * For a full description of the module, visit the project page:
   https://www.drupal.org/project/standwithukraine

 * To submit bug reports and feature suggestions, or track changes:
   https://www.drupal.org/project/issues/standwithukraine


REQUIREMENTS
------------

This module requires no modules outside of Drupal core.


INSTALLATION
------------

 * Install as you would normally install a contributed Drupal module. Visit
   https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

 * Configure the user permissions in Administration » People » Permissions:

   - Administer StandWithUkraine

     Users with this permission will configure module settings.

   - Hide the message and use the original favicon.

     Users with this permission will not see the message and overridden favicon.

 * Customize the module settings in Administration » Configuration »
   User interface » StandWithUkraine 🇺🇦.


MAINTAINERS
-----------

Current maintainers:
 * Oleksandr Horbatiuk (chmez) - https://www.drupal.org/user/3071411
